@@ -3,6 +3,7 @@
 import json
 import logging
 import time
+from typing import Dict, Optional
 import requests
 from requests.exceptions import HTTPError
 
@@ -121,7 +122,7 @@ class Driver:
         self._headers = {"Authorization": "Bearer " + self._token}
 
     @error_report
-    def post(self, endpoint, params=None, data=None, multipart_formdata=None):
+    def post(self, endpoint, params=None, data=None, multipart_formdata=None) -> Dict:
         """Post object to endpoint.
 
         Args:
@@ -144,7 +145,7 @@ class Driver:
         return mm_response.json()
 
     @error_report
-    def get(self, endpoint, params=None, raw=False):
+    def get(self, endpoint, params=None, raw=False) -> Dict:
         """Get object from endpoint.
 
         Args:
@@ -232,7 +233,7 @@ class Driver:
         data = {"trigger_id": trigger_id, "url": dialog_url, "dialog": view}
         self.post("/actions/dialogs/open", data=data)
 
-    def upload_file(self, channel_id, file):
+    def upload_file(self, channel_id, file) -> Dict:
         """Uploads a file that can later be attached to a post.
 
         Instead of passing the filepath, we instead expect a
@@ -272,7 +273,7 @@ class MattermostDispatcher(Dispatcher):  # pylint: disable=too-many-public-metho
 
     @classmethod
     @BACKEND_ACTION_LOOKUP.time()
-    def platform_lookup(cls, item_type, item_name):
+    def platform_lookup(cls, item_type, item_name) -> Optional[str]:
         """Call out to the chat platform to look up, e.g., a specific user ID by name.
 
         Args:
@@ -610,7 +611,7 @@ class MattermostDispatcher(Dispatcher):  # pylint: disable=too-many-public-metho
         """Construct a basic Markdown-formatted text element."""
         return text
 
-    def select_element(self, action_id, choices):
+    def select_element(self, action_id, choices) -> Dict:
         """Construct a basic selection menu with the given choices.
 
         Args:
@@ -644,7 +645,10 @@ class MattermostDispatcher(Dispatcher):  # pylint: disable=too-many-public-metho
           choices (list): List of (display, value) tuples
           default (tuple: Default (display, value) to preselect
           confirm (bool): If true (and the platform supports it), prompt the user to confirm their selection
-          optional: (optional) If set to True, the field will return NoneType is not specified.
+          optional (bool): If set to True, the field will return NoneType is not specified.
+
+        Returns:
+            data (dict): select element
         """
         default_text, default_value = default
         logger.info("Ignoring: select_element_interactive has no confirm: %s", confirm)
